=====
Tools
=====

Camera configuration
--------------------
.. automodule:: crappy.tool.cameraConfig
   :members:

Comedi Bind
-----------
.. automodule:: crappy.tool.comedi_bind
   :members:

Discorrel tool
--------------
.. automodule:: crappy.tool.discorrel
   :members:

Discorrel configuration
-----------------------
.. automodule:: crappy.tool.discorrelConfig
   :members:

Disve tool
----------
.. automodule:: crappy.tool.disve
   :members:

Disve configuration
-------------------
.. automodule:: crappy.tool.disveConfig
   :members:

Fields
------
.. automodule:: crappy.tool.fields
   :members:

FT232H
------
.. automodule:: crappy.tool.ft232h.ft232h
   :members:

FT232H Server
-------------
.. automodule:: crappy.tool.ft232h.ft232h_server
   :members:

GPU Correl
----------
.. automodule:: crappy.tool.gpucorrel
   :members:

I2C Message FT232H
------------------
.. automodule:: crappy.tool.ft232h.i2c_message_ft232h
   :members:

Py SPCM
-------
.. automodule:: crappy.tool.pyspcm
   :members:

USB server
----------
.. automodule:: crappy.tool.ft232h.usb_server
   :members:

Video extenso
-------------
.. automodule:: crappy.tool.videoextenso
   :members:

Video extenso configuration
---------------------------
.. automodule:: crappy.tool.videoextensoConfig
   :members:
